@@ -11,7 +11,7 @@
 
  Peter Beerli 1997, Seattle
  beerli@genetics.washington.edu
- $Id: broyden.c,v 1.48 2001/04/09 17:14:49 beerli Exp $
+ $Id: broyden.c,v 1.50 2001/04/16 17:24:36 beerli Exp $
 -------------------------------------------------------*/
 extern double norm (double *d, long size);
 
@@ -59,7 +59,7 @@ double psi (double lamda, helper_fmt * helper);
 void grad2loggrad (double *param, long *indeks, double *d, long nn, long profilenum);
 void log_param0 (double *param, double *lparam, long nn);
 void create_apg0 (double *apg0, nr_fmt * nr, timearchive_fmt * tyme);
-void create_multiapg0 (double *apg0, nr_fmt * nr, long rep, long locus);
+
 
 void force_sametheta (double *param, worldoption_fmt *wopt, long numpop);
 void force_samemigration (double *param, worldoption_fmt *wopt, long numpop);
@@ -484,6 +484,106 @@ destroy_nr (nr_fmt * nr, world_fmt * world)
     }
   free (nr);
 }
+/*
+double
+calc_locus_like (nr_fmt * nr, double *param, double *lparam, long locus)
+{
+  long g, r, j,copies;
+  int msta, msto;
+  double gsum = 0;
+  double ***apg0;
+  double apgmax = -DBL_MAX;
+  double ***apgall = nr->apg;
+  double *apg;
+  double *apg0r;
+  timearchive_fmt tyme;
+  tarchive_fmt *tl;
+  double *localparam;
+  double *geo = nr->world->data->geo;
+  double *lgeo = nr->world->data->lgeo;
+  double *locallparam;
+  double *sm;
+  localparam = (double *) calloc((2*nr->partsize + nr->numpop),
+				 sizeof(double));
+  locallparam = localparam + nr->partsize;
+  sm = localparam + 2 * nr->partsize;
+  memcpy(localparam,param,sizeof(double)*nr->partsize);
+  memcpy(locallparam,lparam,sizeof(double)*nr->partsize);
+
+  nr->PGC[locus] = 0.0;
+  apg0 = nr->apg0;
+  // precalculations of sum(k M) and M geo
+  for(r=0;r<nr->numpop;r++)
+    {
+      msta = nr->mstart[r];
+      msto = nr->mend[r];
+      for (j = msta; j < msto; j++)
+	{
+	  sm[r] += geo[j] * localparam[j];
+	  locallparam[j] += lgeo[j];
+	}
+    }
+  // loop over replicates before normalizing
+  gsum = 0;
+  for (r = nr->repstart; r < nr->repstop; r++)
+    {
+      apg = apgall[r][locus];
+      apg0r = apg0[r][locus];
+      tyme = nr->world->atl[r][locus];
+      //first element
+      tl = &(tyme.tl[0]);
+      copies = tl->copies-1;
+      gsum += copies;
+      if(copies>0)
+	apg[0] = ln_copies(copies) + 
+	  probG2 (localparam, locallparam, sm, 
+		  tl->kt, tl->km, tl->p, 
+		  tl->mindex, 
+		  nr->mstart, nr->mend, 
+		  nr->numpop) - apg0r[0];
+      else
+	apg[0] = -DBL_MAX;
+
+      if (apg[0] > apgmax)
+	apgmax = apg[0];
+
+      //other elements
+      for (g = 1; g < tyme.T; g++)
+        {
+	  tl = &(tyme.tl[g]);
+	  copies = tl->copies;
+	  gsum += copies;
+	  apg[g] = ln_copies(copies) + 
+	    probG2 (localparam, locallparam, sm, 
+		    tl->kt, tl->km, tl->p, 
+		    tl->mindex, 
+		    nr->mstart, nr->mend, 
+		    nr->numpop) - apg0r[g];
+	  if (apg[g] > apgmax)
+	    apgmax = apg[g];
+	}
+    } // end replicates
+
+  nr->PGC[locus] = 0.0;
+  // loop over replicates normalizing
+  for (r = nr->repstart; r < nr->repstop; r++)
+    {
+      apg = nr->apg[r][locus];
+      if(apg[0] > -DBL_MAX)
+	apg[0] -= apgmax;
+      for (g = 1; g < nr->world->atl[r][locus].T; g++)
+        {
+	  apg[g] -= apgmax;
+	  if(apg[g] > -40.)
+	    nr->PGC[locus] += exp (apg[g]);
+	}
+    }
+  nr->apg_max[locus] = apgmax;
+  nr->llike = apgmax + log (nr->PGC[locus]) - log (gsum);
+  free(localparam);
+  return nr->llike;
+}
+*/
 
 double
 calc_locus_like (nr_fmt * nr, double *param, double *lparam, long locus)
@@ -512,7 +612,6 @@ calc_locus_like (nr_fmt * nr, double *param, double *lparam, long locus)
 
   nr->PGC[locus] = 0.0;
   apg0 = nr->apg0;
-  gsum = 0;
 
   for(r=0;r<nr->numpop;r++)
     {
@@ -524,45 +623,66 @@ calc_locus_like (nr_fmt * nr, double *param, double *lparam, long locus)
 	  locallparam[j] += lgeo[j];
 	}
     }
+  gsum = 0;
   for (r = nr->repstart; r < nr->repstop; r++)
     {
       apg = apgall[r][locus];
       apg0r = apg0[r][locus];
       tyme = nr->atl[r][locus];
-      //memset(apg, 0 ,sizeof(double)*tyme.T);
-      //probG3(apg,apg0r, &tyme, nr->numpop, &apgmax, localparam, locallparam, sm);
-      
-      	for (g = 0; g < tyme.T; g++)
-	{
+      //first element
+      tl = &(tyme.tl[0]);
+      copies = tl->copies-1;
+      gsum += copies;
+      if(copies>0)
+	apg[0] = ln_copies(copies) + probG2 (localparam, locallparam, sm, 
+					     tl->kt, tl->km, tl->p, 
+					     tl->mindex, 
+					     nr->mstart, nr->mend, 
+					     nr->numpop) - apg0r[0];
+      else
+	apg[0] = -DBL_MAX;
+      if(apgmax<apg[0])
+	apgmax = apg[0];
+      //other elements
+      for (g = 1; g < tyme.T; g++)
+        {
 	  tl = &(tyme.tl[g]);
-	  copies = g > 0 ? tl->copies : tl->copies-1;
+	  copies = tl->copies;
 	  gsum += copies;
 	  apg[g] = ln_copies(copies) + probG2 (localparam, locallparam, sm, 
-			   tl->kt, tl->km, tl->p, tl->mindex, 
-			   nr->mstart, nr->mend, nr->numpop) - apg0r[g];
+					       tl->kt, tl->km, tl->p, 
+					       tl->mindex, 
+					       nr->mstart, nr->mend, 
+					       nr->numpop) - apg0r[g];
 	  if (apg[g] > apgmax)
 	    apgmax = apg[g];
 	}
+    }
+  for (r = nr->repstart; r < nr->repstop; r++)
+    {
+      apg = apgall[r][locus];
+      apg0r = apg0[r][locus];
+      tyme = nr->atl[r][locus];
+      //first element
+      tl = &(tyme.tl[0]);
       // first element
-	//gsum = tyme.tl[0].copies - 1;
       apg[0] -= apgmax;
-      nr->PGC[locus] = /*gsum */ exp (apg[0]);
+      nr->PGC[locus] += exp (apg[0]);
       // all other elements
       for (g = 1; g < tyme.T; g++)
 	{
-	  copies = tyme.tl[g].copies;
-	  //gsum += copies;
-	  apg[g] -= apgmax;// + ln_copies(copies);
+	  apg[g] -= apgmax;
 	  if(apg[g] > -40.)
-	    nr->PGC[locus] += /*copies */ exp (apg[g]);
+	    nr->PGC[locus] += exp (apg[g]);
 	}
-    }
+    } // replicates
   nr->apg_max[locus] = apgmax;
   nr->llike = apgmax + log (nr->PGC[locus]) - log (gsum);
   free(localparam);
   return nr->llike;
 }
 
+
 double ln_copies(long n)
 {
   switch(n)
@@ -774,15 +894,11 @@ gradient (double *d, nr_fmt * nr, long locus)
 	  if(nr->apg[r][locus][g] < -40.)
 	    continue;
 	  tl = nr->world->atl[r][locus].tl;
-	  //	  	  if (nr->apg[r][locus][g] > -100)
-	  // {
-	  //copies = (g > 0) ? tl[g].copies : tl[g].copies - 1;
-	  expapg = /*copies */ exp (nr->apg[r][locus][g]);
-	  if(expapg==0.)
-	    continue;
+	  expapg = exp (nr->apg[r][locus][g]);
 	  for (pop = 0; pop < numpop; pop++)
 	    {
-	      nr->parts[pop] = -tl[g].p[pop] / thetas[pop] + tl[g].kt[pop] / (thetas[pop] * thetas[pop]);
+	      nr->parts[pop] = -tl[g].p[pop] / thetas[pop] 
+		+ tl[g].kt[pop] / (thetas[pop] * thetas[pop]);
 	      
 	      msta = nr->mstart[pop];
 	      msto = nr->mend[pop];
@@ -790,7 +906,8 @@ gradient (double *d, nr_fmt * nr, long locus)
 	      for (i = msta; i < msto; i++)
 		{
 		  if (nr->param[i] > 0.)
-		    nr->parts[i] = ((tl[g].mindex[i] / nr->param[i]) - geo[i] * tl[g].km[pop]);
+		    nr->parts[i] = ((tl[g].mindex[i] / nr->param[i]) 
+				    - geo[i] * tl[g].km[pop]);
 		}
 	    }
 	  z = 0;
@@ -799,10 +916,8 @@ gradient (double *d, nr_fmt * nr, long locus)
 	      ii = (nr->profilenum > 0) ? nr->indeks[z++] : i;
 	      d[i] += expapg * nr->parts[ii];
 	    }
-	  //}
 	}
     }
-  //  force_symmetric_d (model, nr, nn);
 }
 
 /* calculates the derivatives for the different
@@ -1311,42 +1426,21 @@ void
 create_apg0 (double *apg0, nr_fmt * nr, timearchive_fmt * tyme)
 {
   long g;
+  long copies;
   /* Prob(G|Param0) */
   for (g = 0; g < tyme->T; g++)
     {
-      apg0[g] = probG (tyme->param0, tyme->lparam0, &tyme->tl[g], nr);
+      if(g>0)
+	copies = tyme->tl[g].copies;
+      else
+	copies= tyme->tl[g].copies-1;
+      if(copies==0)
+	apg0[g]=-DBL_MAX;
+      else
+	apg0[g] = probG (tyme->param0, tyme->lparam0, &tyme->tl[g], nr);
     }
 }
 
-void
-create_multiapg0 (double *apg0, nr_fmt * nr, long rep, long locus)
-{
-  long g, r;
-  //  double lsteps = log((double) nr->world->options->lsteps) ;
-  double *tmp;
-  double tmpmax;
-  //double gsum=0;
-  tmp = (double *) calloc (nr->repstop, sizeof (double));
-  for (g = 0; g < nr->world->atl[rep][locus].T; g++)
-    {
-      //gsum += nr->atl[rep][locus].tl[g].copies;
-      tmpmax = -DBL_MAX;
-      for (r = nr->repstart; r < nr->repstop; r++)
-	{
-	  tmp[r] =		//lsteps +
-	    probG (nr->world->atl[r][locus].param0, nr->world->atl[r][locus].lparam0, &nr->world->atl[rep][locus].tl[g], nr) - nr->world->chainlikes[locus][r];
-	  if (tmp[r] > tmpmax)
-	    tmpmax = tmp[r];
-	}
-      apg0[g] = 0.0;
-      for (r = nr->repstart; r < nr->repstop; r++)
-	apg0[g] += exp (tmp[r] - tmpmax);
-      apg0[g] = log (apg0[g]) + tmpmax;	//
-      //-  log(nr->repstop-nr->repstart);//+ log(nr->repstop-nr->repstart);
-    }
-  free (tmp);
-}
-
 double
 logprob_noevent (world_fmt * world, long interval)
 {
