@@ -15,7 +15,7 @@
  Peter Beerli 1996-1998, Seattle
  beerli@genetics.washington.edu
 
- $Id: combroyden2.c,v 1.65 2001/04/09 17:59:04 beerli Exp $
+ $Id: combroyden2.c,v 1.68 2001/04/21 05:24:49 beerli Exp $
 
 -------------------------------------------------------*/
 
@@ -174,8 +174,7 @@ estimateParameter (long rep, long G, world_fmt * world, option_fmt *options, dou
 #endif
 
   memcpy(param, world->param0, sizeof(double) * nr->numpop2);
-  if (strchr (world->options->custm2, '0') || 
-      strchr (world->options->custm2, 'c'))
+  if (strpbrk (world->options->custm2, "0c"))
     {
       if(kind==SINGLELOCUS && world->options->custm2[world->numpop2] == 'c')
 	trials =  maximize(param, world, nr, kind, repkind);
@@ -779,8 +778,8 @@ which_calc_like (long repkind)
       break;
     case MULTIPLECHAIN:
     case MULTIPLERUN:
-      //calc_like = (double (*)(nr_fmt *,double *, long)) calc_locus_like;
-      calc_like = (double (*)(nr_fmt *, double *, double *, long)) norm_constant;
+      calc_like = (double (*)(nr_fmt *,double *, double *, long)) calc_locus_like;
+      //calc_like = (double (*)(nr_fmt *, double *, double *, long)) norm_constant;
       // break;
     default:
       calc_like = (double (*)(nr_fmt *, double *, double *, long)) calc_locus_like;
@@ -891,8 +890,11 @@ setup_parameter0 (world_fmt * world, nr_fmt * nr, long repkind, long repstart, l
 			create_apg0 (nr->apg0[r][locus], nr, &world->atl[r][locus]);
 		      interpolate_like (nr, locus);
 		    }
-		  for (r = repstart; r < repstop; r++)
-		    create_multiapg0 (nr->apg0[r][locus], nr, r, locus);
+		  else
+		    {
+		      for (r = repstart; r < repstop; r++)
+			create_multiapg0 (nr->apg0[r][locus], nr, r, locus);
+		    }
 		}
 	    }
 	}
@@ -1060,9 +1062,9 @@ maximize(double *param, world_fmt *world, nr_fmt *nr, long analystype, long repk
       	lamda = 10.;//calc_line (&helper, -10., 0.1, 10., 
       //   world->locus > 1 ? psilo : psi);//line_search(dv,gxv,analystype==MULTILOCUS ? psilo : psi,
       // nr,oldL);
-      else
+	else
 	lamda = calc_line (&helper, -10., 0.1, 10., 
-			 world->locus > 1 ? psilo : psi);
+		 world->locus > 1 ? psilo : psi);
       //       	printf("\n");
       //      printf("lamda=%f, %s\n",lamda,analystype==MULTILOCUS ? "psilo" : "psi");
       //reset_z++;
