@@ -14,12 +14,12 @@
   With help of Joe Felsenstein (joe@genetics.washington.edu),
   Mary Kuhner and Jon Yamato (mkkuhner@genetics.washington.edu)
 
-  $Id: definitions.h,v 1.53 2001/04/11 16:53:49 beerli Exp $
+  $Id: definitions.h,v 1.57 2001/04/21 05:24:49 beerli Exp $
 
   *----------------------------------------------------------------
   */
 #ifndef MIGRATEVERSION
-#define MIGRATEVERSION "1.0.1"
+#define MIGRATEVERSION "1.0.4"
 #endif
 
 #define MAINTAINER "Peter Beerli <beerli@genetics.washington.edu>"
@@ -137,7 +137,7 @@ typedef unsigned char boolean;
 #define SNPTYPES      "nu"
 #define ALLELETYPES   "amb" /*a=infinite allele,m=stepwise, b=brownian*/
 
-
+#define CRLF "\r\n"
 /*=================================================================
   SPECIFIC FOR MIGRATE
 
@@ -152,6 +152,7 @@ typedef unsigned char boolean;
 #define MAXALLELES            93
 #define MAXBUFSIZE        100000      
 #define LINESIZE            1024	/* setting this smaller can break */
+#define LONGLINESIZE       10000	/* setting this smaller can break */
 #define STRSIZE              255	/* setting this smaller can break */
 #define DEFAULT_NMLENGTH      10	/* length of individual names */
 #define DEFAULT_ALLELENMLENGTH 6	/* length of allele names */
