@@ -8,7 +8,7 @@
  moved out from world.c                                                                                                               
  Peter Beerli 2000, Seattle
  beerli@genetics.washington.edu
- $Id: lrt.c,v 1.7 2001/04/11 16:53:49 beerli Exp $
+ $Id: lrt.c,v 1.8 2001/04/23 17:32:29 beerli Exp $
 -------------------------------------------------------*/
 #define SICK_VALUE    -1
 #include "migration.h"
@@ -71,7 +71,7 @@ void
 print_lratio_test (world_fmt * world, long *Gmax)
 {
   long c;
-  long r, locus;
+  long r,  locus;
   long df;
   int header;
   nr_fmt *nr;
@@ -79,6 +79,9 @@ print_lratio_test (world_fmt * world, long *Gmax)
   double *param1;
   long *maxwhich;
   long maxnum = 0;
+  long rep = !world->options->replicate ? 0 : 
+    (world->options->replicatenum == 0 ? 
+     world->options->lchains : world->options->replicatenum); 
   long repstop = world->repstop;
   param0 = (double *) calloc (1, sizeof (double) * (world->numpop2 + 1));
   param1 = (double *) calloc (1, sizeof (double) * (world->numpop2 + 1));
@@ -99,16 +102,21 @@ print_lratio_test (world_fmt * world, long *Gmax)
 	create_apg0 (nr->apg0[0][locus], nr, &world->atl[0][locus]);
     }
   if(world->loci>1)
-    locus=world->loci;
+    {
+      locus=world->loci;
+      rep = 0;
+    }
   else
-    locus=0;
+    {
+      locus=0;
+    }
   for(c=0; c<world->options->lratio->counter; c++)
     {
       PAGEFEEDWORLD;
       header = (c == 0) ? HEADER : NOHEADER;
       if (world->options->lratio->data[c].type == MLE)
 	{
-	  memcpy(param1,world->atl[0][locus].param,
+	  memcpy(param1,world->atl[rep][locus].param,
 		 sizeof(double)*world->numpop2);
 	  df = set_test_param (param0, 
 			       world->options->lratio->data[c].value1, 
@@ -421,6 +429,9 @@ set_test_param (double *param, char *strp, world_fmt * world, long lrline, long
   long numpop = world->numpop;
   char *tmp, *ss, *paramtype;
   double *meanparam, mean;
+long repstop = !world->options->replicate ? 0 : 
+    (world->options->replicatenum == 0 ? 
+     world->options->lchains : world->options->replicatenum); 
   ss = (char *) calloc (1, sizeof (char) * LINESIZE);
   tmp = (char *) calloc (1, sizeof (char) * LINESIZE);
   paramtype = (char *) calloc (1, sizeof (char) * world->numpop2);
@@ -431,7 +442,7 @@ set_test_param (double *param, char *strp, world_fmt * world, long lrline, long
   if (world->loci - world->skipped > 1)
     meanparam = world->atl[0][world->loci].param;
   else
-    meanparam = world->atl[0][0].param;
+    meanparam = world->atl[repstop][0].param;
   while (ss[zzz] != '\0')
     {
       tmp[i] = ss[zzz++];
