@@ -21,7 +21,6 @@
   I.e. the tips are at tyme '0', and the root node has the largest
   value for 'tyme'. 
   
-
   */
 
 typedef char allele_type[DEFAULT_ALLELENMLENGTH];
@@ -39,7 +38,8 @@ typedef struct lr_data_fmt
 {
   short type;
   long elem;
-  char *value;
+  char *value1;
+  char *value2;
 }
 lr_data_fmt;
 
@@ -53,8 +53,7 @@ lratio_fmt;
 
 typedef struct valrec
 {
-  double rat, ratxi, ratxv, zz, z1, y1, ww1, zz1, ww2, zz2, z1zz, z1yy,
-    xiz1, xiy1xv, ww1zz1, vv1zz1, ww2zz2, vv2zz2;
+  double rat, ratxi, ratxv, zz, z1, y1, ww1, zz1, ww2, zz2, z1zz, z1yy, xiz1, xiy1xv, ww1zz1, vv1zz1, ww2zz2, vv2zz2;
 }
 valrec;
 
@@ -76,7 +75,6 @@ typedef struct seqmodel_fmt
   long endsite;
   double xi, xv, ttratio, fracchange;
   long *sites;
-  tbl_fmt tbl;
   long *alias;
   long *ally;
   long *category;
@@ -84,14 +82,6 @@ typedef struct seqmodel_fmt
   long weightsum;
   long *aliasweight;
   long *location;
-  double **term;
-  double **slopeterm;
-  double **curveterm;
-  val *mp;
-  contribarr *contribution;
-  contribarr like;
-  contribarr nulike;
-  contribarr clai;
   long addon;
 
 
@@ -108,6 +98,11 @@ typedef struct _data
   FILE *sumfile;
   FILE *distfile;
   FILE *geofile;
+#ifdef UEP
+  FILE *uepfile;
+  long **uep;
+  long uepsites;
+#endif
   char *****yy;
   double *geo;
   double *lgeo;
@@ -134,6 +129,7 @@ typedef long quad_fmt[4];
 
 typedef struct _option
 {
+  char **buffer; //pointer to buffer when MPI-worker otherwise NULL
   FILE *parmfile;
   FILE *seedfile;
   FILE *logfile;
@@ -141,8 +137,8 @@ typedef struct _option
   long nmlength;		/* length of individual names */
   long popnmlength;		/* length of population names */
   long allelenmlength;		/* length of allele names */
-  char *custm;
-  char *custm2;
+  char *custm; /* custom migration matrix: theta are first */
+  char *custm2; /*custom migration matrix: theta on diagonal*/
   long zeron;
   long *zeroparam;
   long constn;
@@ -159,6 +155,8 @@ typedef struct _option
   boolean progress;
   boolean verbose;
   boolean writelog;
+  boolean uep;
+  double ueprate;
   boolean movingsteps;
   double acceptfreq;
   boolean printdata;
@@ -192,9 +190,14 @@ typedef struct _option
   char distfilename[256];
   char geofilename[256];
   char bootfilename[256];
-  char title[LINESIZE+1];
+#ifdef UEP
+  char uepfilename[256];
+#endif
+  char title[LINESIZE + 1];
   lratio_fmt *lratio;
-  long fsttype;
+  boolean aic;
+  double aicmod;
+  char fsttype;
   boolean printfst;
   short profile;
   char profilemethod;
@@ -212,7 +215,9 @@ typedef struct _option
   long micro_threshold;
   double **steps;
   boolean interleaved;
+  double seqerror;
   double *ttratio;
+  boolean fastlike;
   boolean freqsfrom;
   long categs;
   double *rate;
@@ -233,9 +238,11 @@ typedef struct _option
   long inseed;
   long saveseed;
   /* mcmc options */
+  boolean bayes_update;
   short thetaguess;
   short migrguess;
   boolean gamma;
+  double alphavalue;
   long burn_in;
   short heating;
   double *thetag;
@@ -255,11 +262,13 @@ typedef struct _option
   long replicatenum;
   long gridpoints;
   long numpop;
-  double heat[4];
+  double heat[20];
+  long heating_interval;
+  long heated_chains;
   /* save genealogy summary options */
   boolean readsum;
   boolean writesum;
-  /* threading over loci*/
+  /* threading over loci */
   int cpu;
 }
 option_fmt;
@@ -276,13 +285,19 @@ typedef struct _node
   long actualpop;
   long id;
   xarray_fmt x;
+#ifdef UEP
+  long *uep;
+#endif
   double *s;
-  double lxmax;
+  double *scale;
   char *nayme;
   boolean top;
   boolean dirty;
-  double v, tyme, length, xcoord;
-  short ycoord, ymin, ymax;
+  double v, tyme;
+  double length;
+  // double xcoord;
+  //short ycoord,  ymin, ymax;
+  //double status;?????
 }
 node;
 
@@ -384,18 +399,121 @@ typedef struct _mighistloci_fmt
 }
 mighistloci_fmt;
 
+typedef struct _worldoption
+{
+  boolean gamma;
+  double alphavalue;
+  short migration_model;
+  char *custm;
+  char *custm2;
+  double *thetag;
+  double *mg;
+  long zeron;
+  long *zeroparam;
+  long constn;
+  long *constparam;
+  long symn;
+  long sym2n;
+  twin_fmt *symparam;
+  quad_fmt *sym2param;
+  long mmn;
+  long *mmparam;
+  boolean mixplot;
+  boolean progress;
+  boolean writelog;
+  FILE *logfile;
+  boolean plotnow;
+  boolean verbose;
+  boolean replicate;
+  boolean gelman;
+  double lcepsilon;
+  boolean simulation;
+  char datatype;
+  long lsteps;
+  double loglsteps;
+  long treeprint;
+  long movingsteps;
+  double acceptfreq;
+  long rcategs;
+  long categs;
+  long heating;
+  long heated_chains;
+  long heating_interval;
+  char profilemethod;
+  boolean printprofile;
+  boolean printprofsummary;
+  long profileparamtype;
+  long df;
+  long lchains;
+  long replicatenum;
+  long micro_threshold;
+  long micro_stepnum;
+  double **steps;
+  double *rrate;
+  double *rate;
+  double *probcat;
+  long pluschain;
+  boolean mighist;
+  long burn_in;
+  boolean plot;
+  long plotmethod;
+  long plotintervals;
+  double plotrange[4];
+  short plotscale;
+  long plotvar;
+  double *plotxvalues;
+  double *plotyvalues;
+  lratio_fmt *lratio;
+  boolean aic;
+  double aicmod;
+  double lambda;
+#ifdef UEP
+  boolean uep;
+  double ueprate;
+#endif
+  boolean fastlike;
+}
+worldoption_fmt;
+
+typedef struct _ueptime
+{
+  long size;
+  long   *populations; // population the nodes are in
+  double *ueptime;    // first elementis bottom most time , last elem is
+                      // topmost time,in between are for each migration events
+} ueptime_fmt;
+
+typedef struct _worlddata
+{
+  boolean *skiploci;
+  double *geo;
+  double *lgeo;
+  long *maxalleles;
+  seqmodel_fmt *seq;
+  FILE *sumfile;
+  double freq;
+  double freqlast;
+#ifdef UEP
+  long uepsites;
+#endif
+}
+worlddata_fmt;
+
 typedef struct _world
 {
   /* generalities */
   char *name;
   char *worldname;
-  option_fmt *options;
-  data_fmt *data;
+  worldoption_fmt *options;
+  worlddata_fmt *data;
+#ifdef MPI
+  int *who;
+#endif 
   long loci;
   long skipped;			/*loci with no data */
   long locus;			/* the current locus, if single then set to 0 */
-  long thislocus;               /* the real current locus, the whole locus scheme 
-                                   needs revision*/
+  long thislocus;		/* the real current locus, the whole locus scheme 
+				   needs revision */
   long numpop;
   long numpop2;
   long sumtips;
@@ -413,8 +531,10 @@ typedef struct _world
   /*tree material */
   node **nodep;
   node *root;
+  double treelen;
   long unique_id;
-
+  tbl_fmt tbl;
+  contribarr *contribution;
   /* parameter */
   double *param0;
   double *param00;
@@ -424,6 +544,7 @@ typedef struct _world
   long *lineages;
   timelist_fmt *treetimes;
   double *mig0list;
+  double **migproblist;
   long *design0list;
 
 
@@ -443,26 +564,35 @@ typedef struct _world
   long chains;
   boolean start;		//I need this in estimateParameter() 
   /* reporting */
-  double *likelihood;           /* data likelihoods */
-  long numlike;                 /* how many likelihoods maximally are stored*/
+  double *likelihood;		/* data likelihoods */
+  long numlike;			/* how many likelihoods maximally are stored */
   plotmax_fmt **plotmax;
   quantile_fmt *quantiles;
   double maxdatallike;		/* the maximum log likelihood of a chain */
   double allikemax;		/* the maximum log likelihood  the best tree */
   boolean in_last_chain;	/*for last CHAIN option in print-tree */
-  double param_like;            /* current parameter likelihood [=current chain]*/
-  double **chainlikes;           /* parameter likelihood of replicate/last chains all loci*/
+  double param_like;		/* current parameter likelihood [=current chain] */
+  double **chainlikes;		/* parameter likelihood of replicate/last chains all loci */
   long trials;
   double normd;
   long repkind;
-  long rep;// defines single cahin estimators
-  long replicate; //holdss the replicate we are in
+  long rep;			// defines single cahin estimators
+  long replicate;		//holdss the replicate we are in
   long repstop;
   long lsteps;
   double ***cov;
   long migration_counts;
   char ****plane;
-
+#ifdef UEP
+  double ueplikelihood;
+  double **ueplike;		// contains uep like per tree pop x ueps
+  double ****ueplikestore;	// constains all ueplike long-steps x pop x uep
+  ueptime_fmt *ueptime;		//contains ueptime per tree and mutation
+  ueptime_fmt ***ueptimestore;	//contains all ueptimes
+  long ***ueprootstore;        //stores uep status at root
+  long *oldrootuep;
+  long **uepanc;
+#endif
   long accept;
   long G;
 
@@ -482,9 +612,11 @@ typedef struct _nr_fmt
   long partsize;		/*number of part-variables, fixed per model */
   double *parts;		/* parts of the first and second derivatives */
   double *d;			/* first derivates */
+  double *saved;		/* saved first derivates (used in MPI code)*/
   /* migration parameter array  starts and ends */
   int *mstart;			//link to world->mstart
   int *mend;			//link to world->mend
+  double normd;
   long repkind;
   long repstart;
   long repstop;
@@ -497,27 +629,31 @@ typedef struct _nr_fmt
   world_fmt *world;
   double **dd;			/* second derivatives */
   double *param;		/* changed values of param */
-  double *oparam;		/* saved old parameters */
+  //double *oparam;		/* saved old values of param */
+  double *lparam;		/* changed values of log(param) */
+  //  double *olparam;		/* saved old log(parameters) */
   double llike;			/* parameter LOGlikelihood */
   double lastllike;		/* parameter LOGlikelihood */
   double ollike;		/* old "   " */
   double *datalike;		/*P(D|G) */
   double *locilikes;
   double ***apg0;		/* part-loglikelihoods of param0 */
-  double **apg;			/* part-loglikelihoods of param */
-  double apg_max;		/* maxvalue of apg */
-  double *gamma;
-  long gammaI;
+  double ***apg;		/* part-loglikelihoods of param */
+  double *apg_max;		/* maxvalue of apg */
+  double *rate;                 /* rates for gamma rates*/
+  double *probcat;              /* probabilities for gamma rates*/
+  long categs;                  /* #categories for gamma rates*/
   double alpha;
   long numpop;			/* number of populations */
   long numpop2;			/* 2*numpop */
-  double PGC;			/* uncorrected llike */
-  double oPGC;			/* uncorrected ollike */
+  double *PGC;			/* uncorrected llike */
+  double *oPGC;			/* uncorrected ollike */
   long copy_nr;			/* number of genealogies */
   boolean *skiploci;
   long profilenum;		/* number of profile parameters */
   long *profiles;		/* which profile parameters */
   long *indeks;			/* which noprofile parameters */
+  double *values;               /* profile values*/
 }
 nr_fmt;
 
@@ -527,12 +663,17 @@ typedef struct helper_fmt
   long locus;
   nr_fmt *nr;
   timearchive_fmt **atl;
-  double *param;
+  //double *param;
   long which;
   double weight;
   double ll;
   boolean multilocus;
   boolean boolgamma;
+  long analystype;
+  double *dv;
+  double *xv;
+  double *expxv;
+  double sign;
 }
 helper_fmt;
 
@@ -574,13 +715,16 @@ typedef struct proposal_fmt
   node **line_t;
   node *connect;
   double likelihood;
+  double ueplikelihood;
+  double **ueplike;
+  node *firstuep;
   double time;
   double v;
   double vs;
   xarray_fmt xt;
   xarray_fmt xf;
-  double mf;
-  double mt;
+  double *mf;
+  double *mt;
   node **aboveorigin;
   node **bordernodes;
   long listsize;
@@ -593,7 +737,7 @@ typedef struct proposal_fmt
   long timeslice;
   double *mig0list;
   long *design0list;
-
+  double treelen;
 }
 proposal_fmt;
 
@@ -618,7 +762,16 @@ typedef struct locusdata_fmt
   world_fmt **universe;
   option_fmt *options;
   data_fmt *data;
-} locusdata_fmt;
+}
+locusdata_fmt;
+
+
+
+typedef struct _aic_fmt {
+  double aic;
+  char *pattern;
+  long numparam;
+} aic_fmt;
 
 
 /* here a some definitions which should be remove in a future version
@@ -628,7 +781,7 @@ typedef struct locusdata_fmt
 
 
 /* global variables (this should be not used at all) */
-extern char appl[8];
+extern char appl[20];
 
 #ifdef HIGHBITS
 typedef long longer[3];		/* used in random.c */
