@@ -13,7 +13,7 @@
  
  Peter Beerli 1996, Seattle
  beerli@genetics.washington.edu
- $Id: options.c,v 1.73 2001/04/08 04:24:44 beerli Exp $
+ $Id: options.c,v 1.74 2001/04/11 16:53:49 beerli Exp $
 -------------------------------------------------------*/
 //#include <stdio.h>
 #include <time.h>
@@ -59,7 +59,7 @@ void print_menu_options (world_fmt * world, option_fmt * options, data_fmt * dat
 void print_options (FILE * file, world_fmt * world, option_fmt * options, data_fmt * data);
 void decide_plot (worldoption_fmt * options, long chain, long chains, char type);
 void destroy_options (option_fmt * options);
-long save_parmfile (option_fmt * options);
+long save_parmfile (option_fmt * options, world_fmt *world);
 void read_options_master (option_fmt * options);
 void read_options_worker (char **buffer, option_fmt * options);
 /* private functions */
@@ -90,7 +90,7 @@ void set_plot_values (double **values, double plotrange[], long intervals, short
 void set_grid_param (world_fmt * world, long gridpoints);
 void print_arbitrary_migration_table (FILE * file, world_fmt * world);
 void print_distance_table (FILE * file, world_fmt * world, option_fmt * options, data_fmt * data);
-long save_options_buffer(char buffer[], option_fmt *options);
+long save_options_buffer(char buffer[], option_fmt *options, world_fmt *world);
 
 /*======================================================*/
 void
@@ -1284,7 +1284,7 @@ set_plot_values (double **values, double plotrange[], long intervals, short type
 }
 
 long
-save_parmfile (option_fmt * options)
+save_parmfile (option_fmt * options, world_fmt *world)
 {
   FILE *fp;
   long bufsize;
@@ -1300,7 +1300,7 @@ save_parmfile (option_fmt * options)
     }
   else
     fp = fopen (PARMFILE, "w");
-  bufsize = save_options_buffer(buffer,options);
+  bufsize = save_options_buffer(buffer,options, world);
   fprintf(fp,"%s",buffer);
   fflush (fp);
   printf ("\n\n+++ Parmfile written to current directory +++\n\n");
@@ -1309,7 +1309,7 @@ save_parmfile (option_fmt * options)
 }
 
 
-long save_options_buffer(char *buffer, option_fmt *options)
+long save_options_buffer(char *buffer, option_fmt *options, world_fmt * world)
 {
  long num, i, j, z;
   char nowstr[LINESIZE] = "----";
@@ -1695,14 +1695,13 @@ long save_options_buffer(char *buffer, option_fmt *options)
 	  sprintf (fp, "migration=Own:{ ");
 	  strcat(buffer, fp); 
 	  z = 0;
-	  num = (long) sqrt ((double) options->nummg);
+	  num = (long)(1. +  sqrt (4. * (double) options->nummg + 1.)/2.);
 	  for (i = 0; i < num; i++)
 	    {
 	      for (j = 0; j < num; j++)
 		{
 		  if (i == j)
 		    {
-		      z++;
 		      sprintf (fp, "- ");
 		      strcat(buffer, fp); 
 		    }
@@ -1718,9 +1717,9 @@ long save_options_buffer(char *buffer, option_fmt *options)
 	}
     }
   if(options->gamma)
-    sprintf (fp, "mutation=%s:%f", "GAMMA", options->alphavalue);
+    sprintf (fp, "mutation=%s:%f\n", "GAMMA", options->alphavalue);
   else
-    sprintf (fp, "mutation=%s", "NOGAMMA");
+    sprintf (fp, "mutation=%s\n", "NOGAMMA");
   strcat(buffer, fp); 
 
   sprintf (fp, "fst-type=%s\n", options->fsttype ? "THETA" : "MIGRATION");
@@ -1759,7 +1758,7 @@ long save_options_buffer(char *buffer, option_fmt *options)
   sprintf (fp, "burn-in=%li\n", options->burn_in);
   strcat(buffer, fp); 
 
-  sprintf (fp, "heating=%s", options->heating ? "YES" : "NO\n");	//
+  sprintf (fp, "heating=%s", options->heating ? "YES" : "NO\n");	
   strcat(buffer, fp); 
 
   if (options->heating)
