@@ -15,7 +15,7 @@
                                                                                                                
  Peter Beerli 1996, Seattle
  beerli@genetics.washington.edu
- $Id: options.h,v 1.6 2000/01/25 18:47:38 beerli Exp $
+ $Id: options.h,v 1.12 2001/03/09 16:29:19 beerli Exp $
 -------------------------------------------------------*/
 
 #include "migration.h"
@@ -23,21 +23,20 @@
 extern void create_options (option_fmt ** options);
 extern void init_options (option_fmt * options);
 extern void get_options (option_fmt * options);
-extern void set_param (world_fmt * world, data_fmt * data, option_fmt * options,
-		       long locus);
+extern void set_param (world_fmt * world, data_fmt * data, option_fmt * options, long locus);
 extern void set_profile_options (option_fmt * options);
-extern void print_menu_options (option_fmt * options, world_fmt * world);
-extern void print_options (FILE * file, option_fmt * options,
-			   world_fmt * world);
-extern void print_options_nomcmc (FILE * file, option_fmt * options,
-				  world_fmt * world);
-extern void decide_plot (option_fmt * options, long chain, long chains,
-			 char type);
+extern void print_menu_options (world_fmt * world, option_fmt * options, data_fmt *data);
+extern void print_options (FILE * file,  world_fmt * world, option_fmt * options,data_fmt *data);
+extern void print_options_nomcmc (FILE * file, option_fmt * options, world_fmt * world);
+extern void decide_plot (worldoption_fmt * options, long chain, long chains, char type);
 extern void destroy_options (option_fmt * options);
-extern void read_custom_migration (FILE * file, option_fmt * options,
-				   char *value, long customnumpop);
+extern void read_custom_migration (FILE * file, option_fmt * options, char *value, long customnumpop);
 extern void fillup_custm (long len, world_fmt * world, option_fmt * options);
 extern void save_parmfile (option_fmt * options);
 extern void set_plot (option_fmt * options);
 extern void synchronize_param (world_fmt * world, option_fmt * options);
+extern void resynchronize_param (world_fmt * world);
+extern long save_options_buffer(char *buffer, option_fmt *options);
+extern void read_options_master (option_fmt * options);
+extern void read_options_worker (char **buffer, option_fmt * options);
 #endif /*OPTIONS_INCLUDE */
