@@ -11,7 +11,7 @@
                                                                                                                
  Peter Beerli 1999, Seattle
  beerli@genetics.washington.edu
- $Id: reporter.c,v 1.13 2001/03/09 16:29:19 beerli Exp $
+ $Id: reporter.c,v 1.14 2001/04/16 17:54:36 beerli Exp $
 
 -------------------------------------------------------*/
 
@@ -148,7 +148,8 @@ calc_gelmanr (double *gelmanr, double *gelmanw, double *gelmanb, long len, long
 }
 
 void
-calc_average_biggest_gelmanr (double *gelmanr, long len, double *meanR, double *bigR)
+calc_average_biggest_gelmanr (double *gelmanr, long len, 
+			      double *meanR, double *bigR)
 {
   long i;
   double average = 0;
@@ -169,8 +170,14 @@ calc_average_biggest_gelmanr (double *gelmanr, long len, double *meanR, double *
 void
 print_gelmanr (double average, double biggest)
 {
-  fprintf (stdout, "           Average Gelman's R = %f\n", average);
-  fprintf (stdout, "           Largest Gelman's R = %f [Value < 1.2 show convergence]\n", biggest);
+  if(!isnan(average) && average < 100000)
+    fprintf (stdout, "           Average Gelman's R = %f\n", average);
+  else
+    fprintf (stdout, "           Average Gelman's R = -failed-\n");
+  if(!isnan(biggest) && biggest < 10000000)
+    fprintf (stdout, "           Largest Gelman's R = %f [Value < 1.2 show convergence]\n", biggest);
+  else
+fprintf (stdout, "           Largest Gelman's R = -failed- [Value < 1.2 show convergence]\n");
 }
 
 
